<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" indent="yes"/>
	<xsl:param name="standAloneHTML" select="'true'"/>
	<xsl:template match="/ReleaseNotes">
		<xsl:choose>
			<xsl:when test="$standAloneHTML = 'true'">
				<html>
					<head>
						<title>
							<xsl:text>Release Notes of </xsl:text>
							<xsl:value-of select="@ID"/>
						</title>
						<meta name="Author">Edouard Mercier</meta>
					</head>
					<body>
						<xsl:text>The following table shows the history of </xsl:text>
						<xsl:value-of select="@ID"/>
						<xsl:text> release notes.</xsl:text>
						<xsl:call-template name="_print"/>
					</body>
				</html>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_print"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="_print">
		<table border="1" width="100%">
			<tr>
				<th width="10%">Version</th>
				<th>Content</th>
				<th width="15%">Delivery</th>
			</tr>
			<xsl:apply-templates select="Releases"/>
		</table>
		<div class="copyright">Release notes generated by <strong>
				<i>
					<a href="http://xmlreleasenotes.free.fr" target="_blank">XMLReleaseNotes</a>
				</i>
			</strong>
		</div>
	</xsl:template>
	<xsl:template match="Releases">
		<xsl:for-each select="Release">
			<tr>
				<td>
					<xsl:value-of select="@version"/>-built the '<xsl:value-of select="@buildDate"/>' and delivered the '<xsl:value-of select="@deliveryDate"/>'
				</td>
				<td>
					<xsl:value-of select="Summary"/>
					<br/>
					<xsl:apply-templates select="Tokens"/>
				</td>
				<td>
					<xsl:apply-templates select="Deliveries"/>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="Deliveries">
		<xsl:value-of select="Summary"/>
		<xsl:if test="Delivery">
			<ul>
				<xsl:for-each select="Delivery">
					<li>
						<xsl:value-of select="."/>
					</li>
				</xsl:for-each>
			</ul>
		</xsl:if>
	</xsl:template>
	<xsl:template match="Release/Tokens">
		<xsl:if test="Token">
			<ol>
				<xsl:for-each select="Token">
					<li>type = '<xsl:value-of select="@type"/>'<br/>
						<xsl:call-template name="_printAskingPersons"/>
						<br/>
						<xsl:call-template name="_printContributors"/>
						<br/>
						<xsl:call-template name="_printFix"/>
						<br/>
						<xsl:value-of select="."/>
					</li>
				</xsl:for-each>
			</ol>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printAskingPersons">
		<xsl:if test="count(@askingPersonID | AskingPersons/AskingPerson/@ID) > 0">
			<xsl:text>asking person list:</xsl:text>
			<ul>
				<xsl:for-each select="@askingPersonID | AskingPersons/AskingPerson/@ID">
					<li>
						<xsl:value-of select="."/>
					</li>
				</xsl:for-each>
			</ul>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printContributors">
		<xsl:if test="count(@contributorID | Contributors/Contributor/@ID) > 0">
			<xsl:text>contributor list:</xsl:text>
			<ul>
				<xsl:for-each select="@contributorID | Contributors/Contributor/@ID">
					<li>
						<xsl:value-of select="."/>
					</li>
				</xsl:for-each>
			</ul>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printFix">
		<xsl:if test="@fixID">
			<xsl:text>fixes bug '</xsl:text>
			<xsl:value-of select="@fixID"/>
			<xsl:text>'</xsl:text>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
